pub struct DefaultWriteParams;Expand description
A selector type for write parameters providing reasonable defaults.
If you want to optimize these choices for your architecture, we suggest to
run the benchmarks in the benches directory and write your
own implementation.