MinimalBinary

Struct MinimalBinary 

pub struct MinimalBinary(pub u64);
Structure representing minimal binary coding with a fixed upper bound.

Minimal binary coding does not fit the Codes enum because it is not defined for all integers.

Instances of this structure can be used in contexts in which a DynamicCodeRead, DynamicCodeWrite, StaticCodeRead, StaticCodeWrite or CodeLen implementing minimal binary coding is necessary.

Tuple Fields

0: u64

The upper bound of the minimal binary code.