FuncCodeLen

Struct FuncCodeLen 

pub struct FuncCodeLen(/* private fields */);
A newtype containing a function pointer dispatching the length method for a code.

This is a more efficient way to pass a CodeLen to a method, as a FuncCodeLen does not need to do a runtime test to dispatch the correct method.

Instances can be obtained by calling the new method with a variant of the Codes enum, or by calling the new_with_func method with a function pointer.

Note that since selection of the code happens in the new method, it is more efficient to clone a FuncCodeLen than to create a new one.

Implementations

Source

impl FuncCodeLen

pub const fn new(code: Codes) -> Result<Self, DispatchError>

Returns a new FuncCodeLen for the given code.

The code is canonicalized before the lookup, so equivalent codes yield the same length function.

Errors

The method will return an error if there is no constant for the given code in FuncCodeLen.

pub const fn new_with_func(len_func: fn(u64) -> usize) -> Self

Returns a new FuncCodeLen for the given function.

pub const fn get_func(&self) -> fn(u64) -> usize

Returns the function pointer for the code.