FactoryFuncCodeReader

Struct FactoryFuncCodeReader 

pub struct FactoryFuncCodeReader<E: Endianness, CRF: CodesReaderFactoryHelper<E> + ?Sized>(/* private fields */);
A newtype depending on a CodesReaderFactory and containing a function pointer dispatching the read method for a code.

It is essentially a version of FuncCodeReader that depends on a CodesReaderFactory and its associated CodesReaderFactory::CodesReader instead of a generic CodesRead.

Implementations

Source

impl<E: Endianness, CRF: CodesReaderFactoryHelper<E> + ?Sized> FactoryFuncCodeReader<E, CRF>

pub const fn new(code: Codes) -> Result<Self, DispatchError>

Returns a new FactoryFuncCodeReader for the given code.

The code is canonicalized before the lookup, so equivalent codes yield the same reader.

Errors

The method will return an error if there is no constant for the given code in FactoryFuncCodeReader.

pub const fn new_with_func( read_func: for<'a> fn(&mut <CRF as CodesReaderFactory<E>>::CodesReader<'a>) -> Result<u64, <CRF as CodesReaderFactoryHelper<E>>::Error>, ) -> Self

Returns a new FactoryFuncCodeReader for the given function.

pub const fn get_func( &self, ) -> for<'a> fn(&mut <CRF as CodesReaderFactory<E>>::CodesReader<'a>) -> Result<u64, <CRF as CodesReaderFactoryHelper<E>>::Error>

Returns the function pointer for the code.

pub const fn get<'a>( &self, ) -> FuncCodeReader<E, <CRF as CodesReaderFactory<E>>::CodesReader<'a>>

Returns a FuncCodeReader compatible with CRF’s CodesReaderFactory::CodesReader for a given lifetime 'a.