pub struct ConstCode<const CODE: usize>;Expand description
A zero-sized struct with a const generic parameter representing a code using
the constants exported by the code_consts module.
Methods for all traits are implemented for this struct using a match on the value of the const type parameter. Since the parameter is a constant, the match is resolved at compile time, so there will be no runtime overhead.
If the value is not among those defined in the code_consts module, the
methods will panic.
See the module documentation for more information.
Implementations
Sourceimpl<const CODE: usize> ConstCode<CODE>
impl<const CODE: usize> ConstCode<CODE>
Sourcepub fn read<E: Endianness, CR: CodesRead<E> + ?Sized>(
&self,
reader: &mut CR,
) -> Result<u64, CR::Error>
pub fn read<E: Endianness, CR: CodesRead<E> + ?Sized>( &self, reader: &mut CR, ) -> Result<u64, CR::Error>
Delegates the read method to the DynamicCodeRead implementation.
This inherent method is provided to reduce ambiguity in method resolution.
Sourcepub fn write<E: Endianness, CW: CodesWrite<E> + ?Sized>(
&self,
writer: &mut CW,
n: u64,
) -> Result<usize, CW::Error>
pub fn write<E: Endianness, CW: CodesWrite<E> + ?Sized>( &self, writer: &mut CW, n: u64, ) -> Result<usize, CW::Error>
Delegates to the DynamicCodeWrite implementation.
This inherent method is provided to reduce ambiguity in method resolution.