pub trait CodesWrite<E: Endianness>:
BitWrite<E>
+ GammaWrite<E>
+ DeltaWrite<E>
+ ZetaWrite<E>
+ OmegaWrite<E>
+ MinimalBinaryWrite<E>
+ PiWrite<E>
+ GolombWrite<E>
+ RiceWrite<E>
+ ExpGolombWrite<E>
+ VByteBeWrite<E>
+ VByteLeWrite<E> { }Expand description
Convenience extension trait for writing all the codes supported by the library.
A blanket implementation is provided for all types that implement the necessary traits.
This trait is mainly useful internally to implement the dispatch
traits DynamicCodeWrite and StaticCodeWrite. The user might find it
more useful to define their own convenience trait that includes only the
codes they need.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.