pub struct BufBitReader<E: Endianness, WR: WordRead, RP: ReadParams = DefaultReadParams>where
WR::Word: DoubleType,{ /* private fields */ }Expand description
An implementation of BitRead and BitSeek for a WordRead and a
WordSeek.
This implementation uses a bit buffer to store bits that are not yet read.
The buffer is sized as twice the word size of the underlying WordRead.
Typically, the best choice is to have a buffer that is sized as usize,
which means that the word of the underlying WordRead should be half of
that (i.e., u32 for a 64-bit architecture). However, results will vary
depending on the CPU.
The peek word is equal to the bit buffer. The value returned by
peek_bits contains at least as many bits as the word size (extended with
zeros beyond end of stream): a peek is served by at most one refill, so only
one word of peekable bits can be guaranteed.
The convenience functions from_path and from_file (requiring the
std feature) create a BufBitReader around a buffered file reader.
This implementation is usually faster than BitReader.
The additional type parameter RP is used to select the parameters for the
instantaneous codes, but the casual user should be happy with the default
value. See ReadParams for more details.
For additional flexibility, when the std feature is enabled, this
structure implements std::io::Read. Note that because of coherence
rules it is not possible to implement std::io::Read for a generic
BitRead.
Implementations
Sourceimpl<E: Endianness, WR: WordRead, RP: ReadParams> BufBitReader<E, WR, RP>where
WR::Word: DoubleType,
impl<E: Endianness, WR: WordRead, RP: ReadParams> BufBitReader<E, WR, RP>where
WR::Word: DoubleType,
Sourcepub const fn new(backend: WR) -> Self
pub const fn new(backend: WR) -> Self
Creates a new BufBitReader around a WordRead.
Examples
use dsi_bitstream::prelude::*;
let words: [u32; 2] = [0x0043b59f, 0xccf16077];
let word_reader = MemWordReader::new_inf(&words);
let mut buf_bit_reader = <BufBitReader<BE, _>>::new(word_reader);Sourcepub fn into_inner(self) -> WR
pub fn into_inner(self) -> WR
Consumes this reader and returns the underlying WordRead.