pub struct BufBitWriter<E: Endianness, WW: WordWrite, WP: WriteParams = DefaultWriteParams> { /* private fields */ }Expand description
An implementation of BitWrite for a WordWrite.
This implementation uses a bit buffer to store bits that are not yet
written. The size of the bit buffer is the size of the word used by the
WordWrite, which on most platforms should be usize.
The additional type parameter WP is used to select the parameters for the
instantaneous codes, but the casual user should be happy with the default
value. See WriteParams for more details.
The convenience functions from_path and from_file (requiring the
std feature) create a BufBitWriter around a buffered file writer.
For additional flexibility, when the std feature is enabled, this
structure implements std::io::Write. Note that because of coherence
rules it is not possible to implement std::io::Write for a generic
BitWrite.
Panics on drop
The Drop implementation flushes the buffer, which requires writing to
the backend. If the backend write fails, the drop will panic. To handle
errors gracefully, call flush or into_inner
explicitly before dropping.
Implementations
Sourceimpl<E: Endianness, WW: WordWrite, WP: WriteParams> BufBitWriter<E, WW, WP>
impl<E: Endianness, WW: WordWrite, WP: WriteParams> BufBitWriter<E, WW, WP>
Sourcepub const fn new(backend: WW) -> Self
pub const fn new(backend: WW) -> Self
Creates a new BufBitWriter around a WordWrite.
Examples
#[cfg(not(feature = "std"))]
use dsi_bitstream::prelude::*;
let buffer = Vec::<usize>::new();
let word_writer = MemWordWriterVec::new(buffer);
let mut buf_bit_writer = <BufBitWriter<BE, _>>::new(word_writer);Sourceimpl<E: Endianness, WW: WordWrite, WP: WriteParams> BufBitWriter<E, WW, WP>where
BufBitWriter<E, WW, WP>: BitWrite<E>,
impl<E: Endianness, WW: WordWrite, WP: WriteParams> BufBitWriter<E, WW, WP>where
BufBitWriter<E, WW, WP>: BitWrite<E>,
Sourcepub fn into_inner(self) -> Result<WW, <Self as BitWrite<E>>::Error>
pub fn into_inner(self) -> Result<WW, <Self as BitWrite<E>>::Error>
Returns the backend, consuming this writer after flushing it.