MemWordWriterSlice

Struct MemWordWriterSlice 

pub struct MemWordWriterSlice<W: Word, B> { /* private fields */ }
An implementation of WordRead, WordWrite, and WordSeek for a mutable slice.

Writing beyond the end of the slice will return an error.

Examples

use dsi_bitstream::prelude::*;

let mut words: [u64; 2] = [
    0x0043b59fcdf16077,
    0x702863e6f9739b86,
];

let mut word_writer = MemWordWriterSlice::new(&mut words);

// the stream is read sequentially
assert_eq!(word_writer.word_pos()?, 0);
assert_eq!(word_writer.read_word()?, 0x0043b59fcdf16077);
assert_eq!(word_writer.word_pos()?, 1);
assert_eq!(word_writer.read_word()?, 0x702863e6f9739b86);
assert_eq!(word_writer.word_pos()?, 2);
assert!(word_writer.read_word().is_err());

// you can change position
assert!(word_writer.set_word_pos(1).is_ok());
assert_eq!(word_writer.word_pos()?, 1);
assert_eq!(word_writer.read_word()?, 0x702863e6f9739b86);

// errored set position doesn't change the current position
assert_eq!(word_writer.word_pos()?, 2);
assert!(word_writer.set_word_pos(100).is_err());
assert_eq!(word_writer.word_pos()?, 2);

// we can write and read back!
assert!(word_writer.set_word_pos(0).is_ok());
assert!(word_writer.write_word(0x0b801b2bf696e8d2).is_ok());
assert_eq!(word_writer.word_pos()?, 1);
assert!(word_writer.set_word_pos(0).is_ok());
assert_eq!(word_writer.read_word()?, 0x0b801b2bf696e8d2);
assert_eq!(word_writer.word_pos()?, 1);

Implementations

Source

impl<W: Word, B: AsRef<[W]>> MemWordWriterSlice<W, B>

pub const fn new(data: B) -> Self

Creates a new MemWordWriterSlice from a slice.

pub fn len(&self) -> usize

Returns the number of words in the underlying slice.

pub fn is_empty(&self) -> bool

Returns true if the underlying slice is empty.

pub fn into_inner(self) -> B

Consumes this writer and returns the underlying data.