MemWordWriterVec

Struct MemWordWriterVec 

pub struct MemWordWriterVec<W: Word, B> { /* private fields */ }
An implementation of WordRead, WordWrite, and WordSeek for a mutable vector.

The vector will be extended as new data is written.

Examples

use dsi_bitstream::prelude::*;

let mut words: Vec<u64> = vec![
    0x0043b59fcdf16077,
];

let mut word_writer = MemWordWriterVec::new(&mut words);

// the stream is read sequentially
assert_eq!(word_writer.word_pos()?, 0);
assert!(word_writer.write_word(0).is_ok());
assert_eq!(word_writer.word_pos()?, 1);
assert!(word_writer.write_word(1).is_ok());
assert_eq!(word_writer.word_pos()?, 2);

Implementations

Source

impl<W: Word, B: AsRef<Vec<W>>> MemWordWriterVec<W, B>

pub const fn new(data: B) -> Self

Creates a new MemWordWriterVec from a vector.

pub fn len(&self) -> usize

Returns the number of words in the underlying vector.

pub fn is_empty(&self) -> bool

Returns true if the underlying vector is empty.

pub fn into_inner(self) -> B

Consumes this writer and returns the underlying data.