CodesStats

Struct CodesStats 

pub struct CodesStats<const ZETA: usize = 10, const GOLOMB: usize = 10, const EXP_GOLOMB: usize = 10, const RICE: usize = 10, const PI: usize = 10> {
    pub total: u64,
    pub unary: u64,
    pub gamma: u64,
    pub delta: u64,
    pub omega: u64,
    pub vbyte: u64,
    pub zeta: [u64; ZETA],
    pub golomb: [u64; GOLOMB],
    pub exp_golomb: [u64; EXP_GOLOMB],
    pub rice: [u64; RICE],
    pub pi: [u64; PI],
}
Keeps track of the space needed to store a stream of integers using different codes.

This structure can be used to determine empirically which code provides the best compression for a given stream. You have to update the structure with the integers in the stream; at any time, you can examine the statistics or call best_code to get the best code.

The structure keeps tracks of the codes for which the module code_consts provide constants.

Fields

total: u64

The total number of elements observed.

unary: u64

The total space used to store the elements if they were stored using the unary code.

gamma: u64

The total space used to store the elements if they were stored using the gamma code.

delta: u64

The total space used to store the elements if they were stored using the delta code.

omega: u64

The total space used to store the elements if they were stored using the omega code.

vbyte: u64

The total space used to store the elements if they were stored using the variable byte code.

zeta: [u64; ZETA]

The total space used to store the elements if they were stored using a zeta code. zeta[0] represents ζ₁, zeta[1] represents ζ₂, and so on.

golomb: [u64; GOLOMB]

The total space used to store the elements if they were stored using a Golomb code. golomb[0] represents the Golomb code with modulus 1, golomb[1] represents the Golomb code with modulus 2, and so on.

exp_golomb: [u64; EXP_GOLOMB]

The total space used to store the elements if they were stored using an exponential Golomb code. exp_golomb[0] represents the exponential Golomb code with parameter 0, exp_golomb[1] with parameter 1, and so on.

rice: [u64; RICE]

The total space used to store the elements if they were stored using a Rice code. rice[0] represents the Rice code with log₂(b) = 0, rice[1] with log₂(b) = 1, and so on.

pi: [u64; PI]

The total space used to store the elements if they were stored using a pi code. pi[0] represents π₂, pi[1] represents π₃, and so on.

Implementations

Source

impl<const ZETA: usize, const GOLOMB: usize, const EXP_GOLOMB: usize, const RICE: usize, const PI: usize> CodesStats<ZETA, GOLOMB, EXP_GOLOMB, RICE, PI>

pub fn update(&mut self, n: u64) -> u64

Update the stats with the lengths of the codes for n and return n for convenience.

pub fn update_many(&mut self, n: u64, count: u64) -> u64

Update the stats with count occurrences of n and return n for convenience.

pub fn add(&mut self, rhs: &Self)

Combines additively this stats with another one.

pub fn best_code(&self) -> (Codes, u64)

Returns the best code for the stream and its space usage.

When VByte is the best code, Codes::VByteBe is returned as the canonical representative (both variants have the same bit length).

pub fn get_codes(&self) -> Vec<(Codes, u64)>

Returns a vector of all codes and their space usage, in ascending order by space usage.

pub fn bits_for(&self, code: Codes) -> Option<u64>

Returns the number of bits used by the given code.