Struct dsi_bitstream::utils::CodesStats
source · pub struct CodesStats {
pub unary: u64,
pub gamma: u64,
pub delta: u64,
pub zeta: [u64; 10],
pub golomb: [u64; 20],
}Expand description
Keeps track of the space needed to store a stream of integers using different codes.
This structure can be used to determine empirically which code provides the
best compression for a given stream. You have to update the
structure with the integers in the stream; at any time, you
can examine the statistics or call best_code to get the
best code.
Fields
unary: u64gamma: u64delta: u64zeta: [u64; 10]golomb: [u64; 20]Implementations