CountBitWriter

Struct CountBitWriter 

pub struct CountBitWriter<E: Endianness, BW: BitWrite<E>, const PRINT: bool = false> {
    pub bits_written: usize,
    /* private fields */
}
A wrapper around a BitWrite that keeps track of the number of bits written and optionally prints on standard error the operations performed on the stream.

Fields

bits_written: usize

The number of bits written so far on the underlying BitWrite.

Implementations

Source

impl<E: Endianness, BW: BitWrite<E>, const PRINT: bool> CountBitWriter<E, BW, PRINT>

pub const fn new(bit_write: BW) -> Self

pub fn into_inner(self) -> BW

Consumes this writer and returns the underlying BitWrite.