pub trait WriteParams { }Expand description
Marker trait for write-parameters selector types.
Note that in principle marker traits are not necessary to use selector types, but they are useful to avoid that the user specifies a nonsensical type, and to document the meaning of type parameters.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".