#[non_exhaustive]pub enum Codes {
Unary,
Gamma,
Delta,
Omega,
VByteLe,
VByteBe,
Zeta(usize),
Pi(usize),
Golomb(u64),
ExpGolomb(usize),
Rice(usize),
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unary
Gamma
Delta
Omega
VByteLe
VByteBe
Zeta(usize)
Pi(usize)
Golomb(u64)
ExpGolomb(usize)
Rice(usize)
Implementations
Sourceimpl Codes
impl Codes
Sourcepub const fn canonicalize(self) -> Self
pub const fn canonicalize(self) -> Self
Returns the canonical form of this code.
Some codes are equivalent, in the sense that they are defined differently, but they give rise to the same codewords. Among equivalent codes, there is usually one that is faster to encode and decode, which we call the canonical representative of the equivalence class.
The mapping is:
Sourcepub fn read<E: Endianness, CR: CodesRead<E> + ?Sized>(
&self,
reader: &mut CR,
) -> Result<u64, CR::Error>
pub fn read<E: Endianness, CR: CodesRead<E> + ?Sized>( &self, reader: &mut CR, ) -> Result<u64, CR::Error>
Delegates to the DynamicCodeRead implementation.
This inherent method is provided to reduce ambiguity in method resolution.
Sourcepub fn write<E: Endianness, CW: CodesWrite<E> + ?Sized>(
&self,
writer: &mut CW,
n: u64,
) -> Result<usize, CW::Error>
pub fn write<E: Endianness, CW: CodesWrite<E> + ?Sized>( &self, writer: &mut CW, n: u64, ) -> Result<usize, CW::Error>
Delegates to the DynamicCodeWrite implementation.
This inherent method is provided to reduce ambiguity in method resolution.
Sourcepub const fn to_code_const(&self) -> Result<usize, DispatchError>
pub const fn to_code_const(&self) -> Result<usize, DispatchError>
Converts a code to the constants in the code_consts module used for
ConstCode. This is mostly used to verify that the code is supported
by ConstCode.
The code is canonicalized before the conversion, so equivalent codes map to the same constant.
Errors
Returns DispatchError::UnsupportedCode if the (canonicalized)
code has no corresponding constant in code_consts.
Sourcepub const fn from_code_const(const_code: usize) -> Result<Self, DispatchError>
pub const fn from_code_const(const_code: usize) -> Result<Self, DispatchError>
Converts a value from code_consts to a code.
Errors
Returns DispatchError::UnsupportedCodeConst if the value
does not correspond to any known code constant.