pub struct WordAdapter<W: Word, B> { /* private fields */ }Expand description
An adapter from Read, Write, and Seek, to WordRead,
WordWrite, and WordSeek, respectively.
Instances of this struct can be created using WordAdapter::new. They
turn every standard (possibly seekable) source or destination of bytes (such
as std::fs::File, std::io::BufReader, sockets, etc.) into a source
or destination of words.
Note that the length of adapted files or memory regions must be a multiple of the word length; a nonempty partial-word tail will not be readable.
To provide a sensible value after a failed read of a partial word at the end
of a file, word_pos will always return the position of the underlying
Seek rounded up to the next multiple of the byte size of W. This
approach, however, requires that if you adapt a Seek, its current
position must be a multiple of the byte size of W, or the results of
word_pos will be shifted by the rounding.
Implementations
Sourceimpl<W: Word, B> WordAdapter<W, B>
impl<W: Word, B> WordAdapter<W, B>
Sourcepub const fn new(backend: B) -> Self
pub const fn new(backend: B) -> Self
Creates a new WordAdapter.
Sourcepub fn into_inner(self) -> B
pub fn into_inner(self) -> B
Consumes this adapter and returns the underlying backend.