Helpers and statistics.
CountBitReader and CountBitWriter keep track of the number of bits
read or written to a BitRead and BitWrite, respectively, optionally
printing on standard error the operations performed on the stream.
DbgBitReader and DbgBitWriter print the operations performed by a
BitRead or BitWrite on standard error (only when the std feature
is enabled).
CodesStats keeps track of the space needed to store a stream of
integers using different codes.
With the implied feature, it also provides
sample_implied_distribution, an infinite iterator that returns samples
from the implied distribution of a code, and the helper function
get_implied_distribution.
FindChangePoints finds, using exponential search, the points where a
non-decreasing monotonic function changes value.
Re-exports
pub use stats::CodesStats;pub use stats::CodesStatsWrapper;
Modules
Structs
- Count
BitReader - A wrapper around a
BitReadthat keeps track of the number of bits read and optionally prints on standard error the operations performed on the stream. - Count
BitWriter - A wrapper around a
BitWritethat keeps track of the number of bits written and optionally prints on standard error the operations performed on the stream. - DbgBit
Reader - A wrapper over a
BitReadthat reports on standard error the read operations it performs (only when thestdfeature is enabled). - DbgBit
Writer - A wrapper over a
BitWritethat reports on standard error the write operations it performs (only when thestdfeature is enabled). - Find
Change Points - Iterates over the points where the given function changes value. This only works for monotonic non-decreasing functions.