pub struct CountBitWriter<E: Endianness, BW: BitWrite<E>, const PRINT: bool = false> {
pub bits_written: usize,
/* private fields */
}Expand description
A wrapper around a BitWrite that keeps track of the number
of bits written and optionally prints on standard error the
operations performed on the stream.
Fields
bits_written: usizeThe number of bits written so far on the underlying BitWrite.
Implementations
Sourceimpl<E: Endianness, BW: BitWrite<E>, const PRINT: bool> CountBitWriter<E, BW, PRINT>
impl<E: Endianness, BW: BitWrite<E>, const PRINT: bool> CountBitWriter<E, BW, PRINT>
pub const fn new(bit_write: BW) -> Self
Sourcepub fn into_inner(self) -> BW
pub fn into_inner(self) -> BW
Consumes this writer and returns the underlying BitWrite.